@@ -4,7 +4,7 @@ use warnings;
 
 package Pod::Elemental::Transformer::Splint::AttributeRenderer::HtmlDefault;
 
-our $VERSION = '0.1001'; # VERSION
+our $VERSION = '0.1002'; # VERSION
 # ABSTRACT: Default html attribute renderer
 
 use Moose;
@@ -26,7 +26,10 @@ sub render_attribute {
     push @$items => $settings->{'type'} if defined $settings->{'type'};
     my $req_and_default = '';
 
-    if(!defined $settings->{'default'}) {
+    if(!$settings->{'has_init_arg'}) {
+        $req_and_default = 'not in constructor';
+    }
+    elsif(!defined $settings->{'default'}) {
         $req_and_default = $settings->{'required_text'};
     }
     elsif($settings->{'is_default_a_coderef'}) {
@@ -140,7 +143,7 @@ Pod::Elemental::Transformer::Splint::AttributeRenderer::HtmlDefault - Default ht
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-14.
+Version 0.1002, released 2015-01-18.
 
 =head1 SOURCE
 
