@@ -4,7 +4,7 @@ use warnings;
 
 package Pod::Elemental::Transformer::Splint::MethodRenderer::HtmlDefault;
 
-our $VERSION = '0.1001'; # VERSION
+our $VERSION = '0.1002'; # VERSION
 # ABSTRACT: Default html method renderer
 
 use Moose;
@@ -23,9 +23,9 @@ sub render_method {
     my $named_params = $data->{'named_params'};
     my $return_types = $data->{'return_types'};
 
-    my @html = ();
+    my @html = ('');
     my $table_style = q{style="margin-bottom: 10px; margin-left: 10px; border-collapse: bollapse;" cellpadding="0" cellspacing="0"};
-    my $th_style = q{style="text-align: left; color: #444; background-color: #eee; font-weight: bold;"};
+    my $th_style = q{style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color:};
     my $tr_style = q{style="vertical-align: top;"};
 
     my $method_doc = undef;
@@ -34,8 +34,8 @@ sub render_method {
 
     if(scalar @$positional_params) {
 
-        my $fake_colspan = join '' => (qq{<td $th_style>&#160;</td>} x ($colspan - 1));
-        push @html => qq{<tr $tr_style><td $th_style>Positional parameters</td>$fake_colspan</tr>};
+        my $fake_colspan = join '' => (qq{<td $th_style #eee8e8;">&#160;</td>} x ($colspan - 1));
+        push @html => qq{<tr $tr_style><td $th_style #eee8e8;">Positional parameters</td>$fake_colspan</tr>};
 
         foreach my $param (@$positional_params) {
 
@@ -53,8 +53,8 @@ sub render_method {
     }
     if(scalar @$named_params) {
 
-        my $fake_colspan = join '' => (qq{<td $th_style>&#160;</td>} x ($colspan - 1));
-        push @html => qq{<tr $tr_style><td $th_style>Named parameters</td>$fake_colspan</tr>};
+        my $fake_colspan = join '' => (qq{<td $th_style #e8eee8;">&#160;</td>} x ($colspan - 1));
+        push @html => qq{<tr $tr_style><td $th_style #e8eee8;">Named parameters</td>$fake_colspan</tr>};
 
         foreach my $param (@$named_params) {
             $method_doc = $param->{'method_doc'} if defined $param->{'method_doc'};
@@ -70,8 +70,8 @@ sub render_method {
         }
     }
     if(scalar @$return_types) {
-        my $fake_colspan = join '' => (qq{<td $th_style>&#160;</td>} x ($colspan - 1));
-        push @html => qq{<tr $tr_style><td $th_style>Returns</td>$fake_colspan</tr>};
+        my $fake_colspan = join '' => (qq{<td $th_style #e8e8ee;">&#160;</td>} x ($colspan - 1));
+        push @html => qq{<tr $tr_style><td $th_style #e8e8ee;">Returns</td>$fake_colspan</tr>};
 
         foreach my $return_type (@$return_types) {
             $method_doc = $return_type->{'method_doc'} if defined $return_type->{'method_doc'};
@@ -87,7 +87,7 @@ sub render_method {
         }
     }
     if(scalar @html) {
-        unshift @html => qq{<table $table_style>};
+        unshift @html => '<!-- -->', qq{<table $table_style>};
         push @html => '</table>';
     }
 
@@ -139,6 +139,12 @@ sub param_default_text {
     my $param = shift;
 
     return q{<span style="color: #999;">no default</span>} if !defined $param->{'default'};
+    return $self->parse_pod(sprintf q(default C<%s { }>), $param->{'default_when'}) if ref $param->{'default'} eq 'HASH' && scalar keys %{ $param->{'default'} } == 0;
+    return $self->parse_pod(sprintf q(default C<%s hashref>), $param->{'default_when'}) if ref $param->{'default'} eq 'HASH';
+
+    return $self->parse_pod(sprintf q(default C<%s [ ]>), $param->{'default_when'}) if ref $param->{'default'} eq 'ARRAY' && scalar @{ $param->{'default'} } == 0;
+    return $self->parse_pod(sprintf q(default C<%s arrayref>), $param->{'default_when'}) if ref $param->{'default'} eq 'ARRAY';
+
     return $self->parse_pod(sprintf q{default C<%s coderef>}, $param->{'default_when'}) if ref $param->{'default'} eq 'CODE';
     return $self->parse_pod(sprintf q{default C<%s %s>}, $param->{'default_when'}, $param->{'default'} eq '' ? "''" : $param->{'default'});
 }
@@ -191,7 +197,7 @@ Pod::Elemental::Transformer::Splint::MethodRenderer::HtmlDefault - Default html
 
 =head1 VERSION
 
-Version 0.1001, released 2015-01-14.
+Version 0.1002, released 2015-01-18.
 
 =head1 SOURCE
 
